# SelectExpression

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**expression** | [**ArithmeticExpression**](ArithmeticExpression.md) |  | 
**aggregation** | **str** |  | 
**condition** | [**Condition**](Condition.md) |  | [optional] 
**alias** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

